@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
@@ -29,11 +28,11 @@ search engine.
 """
 import itertools
 from logging import getLogger
+
 from requests.exceptions import ReadTimeout
 
 from internetarchive.auth import S3Auth
 
-
 log = getLogger(__name__)
 
 
@@ -131,6 +130,9 @@ class Search:
                              auth=self.auth,
                              **self.request_kwargs)
         j = r.json()
+        num_found = int(j['response']['numFound'])
+        if not self._num_found:
+            self._num_found = num_found
         if j.get('error'):
             yield j
         yield from j.get('response', {}).get('docs', [])
@@ -148,7 +150,9 @@ class Search:
             j = r.json()
             if j.get('error'):
                 yield j
-            num_found = j['total']
+            num_found = int(j['total'])
+            if not self._num_found:
+                self._num_found = num_found
             self._handle_scrape_error(j)
 
             self.params['cursor'] = j.get('cursor')
